# -*- coding: utf-8 -*-
"""
web2ldap plugin classes for attributes defined for msPerson

$Id: msperson.py,v 1.5 2009/08/18 23:44:31 michael Exp $
"""

import re,pyweblib.forms

from w2lapp.schema.syntaxes import LDAPSyntax,Boolean,DirectoryString,Integer,IA5String,SelectList,syntax_registry


class Gender(SelectList):
  oid = 'Gender-oid'
  desc = 'Representation of human sex (see ISO 5218)'
  attr_value_dict = {
    u'' :u'- not set -',
    u'0':u'Not known',
    u'1':u'Male',
    u'2':u'Female',
    u'9':u'Not specified',
  }

syntax_registry.registerAttrType(
  Gender.oid,[
    '1.3.6.1.4.1.5427.1.389.4.7', # gender (defined for msPerson)
  ]
)


class DateOfBirth(IA5String):
  oid = 'DateOfBirth-oid'
  desc = 'Date of birth: syntax YYYY-MM-DD, see ISO 8601'
  maxLen = 10
  reObj = re.compile('^[0-9]{4}-[0-1][0-9]-[0-3][0-9]$')

syntax_registry.registerAttrType(
  DateOfBirth.oid,[
    '1.3.6.1.4.1.5427.1.389.4.2', # dateOfBirth
  ]
)


class LabeledBICandIBAN(DirectoryString):
  """
  More information:
  http://de.wikipedia.org/wiki/International_Bank_Account_Number
  http://www.pruefziffernberechnung.de/I/IBAN.shtml
  """
  oid = 'LabeledBICandIBAN-oid'
  desc = 'International bank account number (IBAN) syntax (see ISO 13616:1997)'

syntax_registry.registerAttrType(
  LabeledBICandIBAN.oid,[
    '1.3.6.1.4.1.5427.1.389.4.13', # labeledBICandIBAN
  ]
)


# Register all syntax classes in this module
for name in dir():
  syntax_registry.registerSyntaxClass(eval(name))

